from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.explainability_get_config_json_body import \
    ExplainabilityGetConfigJsonBody
from ...models.explainability_get_config_response_200 import \
    ExplainabilityGetConfigResponse200
from ...models.explainability_get_config_response_400 import \
    ExplainabilityGetConfigResponse400
from ...models.explainability_get_config_response_401 import \
    ExplainabilityGetConfigResponse401
from ...models.explainability_get_config_response_500 import \
    ExplainabilityGetConfigResponse500
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: ExplainabilityGetConfigJsonBody,

) -> Dict[str, Any]:
    url = "{}/v1/api/explainability/get_config".format(
        client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    

    

    

    json_json_body = json_body.to_dict()



    

    return {
	    "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[ExplainabilityGetConfigResponse400, ExplainabilityGetConfigResponse401, ExplainabilityGetConfigResponse500, Optional[ExplainabilityGetConfigResponse200]]]:
    if response.status_code == 500:
        response_500 = ExplainabilityGetConfigResponse500.from_dict(response.json())



        return response_500
    if response.status_code == 400:
        response_400 = ExplainabilityGetConfigResponse400.from_dict(response.json())



        return response_400
    if response.status_code == 401:
        response_401 = ExplainabilityGetConfigResponse401.from_dict(response.json())



        return response_401
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: Optional[ExplainabilityGetConfigResponse200]
        if _response_200 is None:
            response_200 = None
        else:
            response_200 = ExplainabilityGetConfigResponse200.from_dict(_response_200)



        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[ExplainabilityGetConfigResponse400, ExplainabilityGetConfigResponse401, ExplainabilityGetConfigResponse500, Optional[ExplainabilityGetConfigResponse200]]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: ExplainabilityGetConfigJsonBody,

) -> Response[Union[ExplainabilityGetConfigResponse400, ExplainabilityGetConfigResponse401, ExplainabilityGetConfigResponse500, Optional[ExplainabilityGetConfigResponse200]]]:
    """Get an explainability config

     Returns the explainability configuration specified by the id.

    Args:
        json_body (ExplainabilityGetConfigJsonBody):

    Returns:
        Response[Union[ExplainabilityGetConfigResponse400, ExplainabilityGetConfigResponse401, ExplainabilityGetConfigResponse500, Optional[ExplainabilityGetConfigResponse200]]]
    """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)

def sync(
    *,
    client: Client,
    json_body: ExplainabilityGetConfigJsonBody,

) -> Optional[Union[ExplainabilityGetConfigResponse400, ExplainabilityGetConfigResponse401, ExplainabilityGetConfigResponse500, Optional[ExplainabilityGetConfigResponse200]]]:
    """Get an explainability config

     Returns the explainability configuration specified by the id.

    Args:
        json_body (ExplainabilityGetConfigJsonBody):

    Returns:
        Response[Union[ExplainabilityGetConfigResponse400, ExplainabilityGetConfigResponse401, ExplainabilityGetConfigResponse500, Optional[ExplainabilityGetConfigResponse200]]]
    """


    return sync_detailed(
        client=client,
json_body=json_body,

    ).parsed

async def asyncio_detailed(
    *,
    client: Client,
    json_body: ExplainabilityGetConfigJsonBody,

) -> Response[Union[ExplainabilityGetConfigResponse400, ExplainabilityGetConfigResponse401, ExplainabilityGetConfigResponse500, Optional[ExplainabilityGetConfigResponse200]]]:
    """Get an explainability config

     Returns the explainability configuration specified by the id.

    Args:
        json_body (ExplainabilityGetConfigJsonBody):

    Returns:
        Response[Union[ExplainabilityGetConfigResponse400, ExplainabilityGetConfigResponse401, ExplainabilityGetConfigResponse500, Optional[ExplainabilityGetConfigResponse200]]]
    """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(
            **kwargs
        )

    return _build_response(response=response)

async def asyncio(
    *,
    client: Client,
    json_body: ExplainabilityGetConfigJsonBody,

) -> Optional[Union[ExplainabilityGetConfigResponse400, ExplainabilityGetConfigResponse401, ExplainabilityGetConfigResponse500, Optional[ExplainabilityGetConfigResponse200]]]:
    """Get an explainability config

     Returns the explainability configuration specified by the id.

    Args:
        json_body (ExplainabilityGetConfigJsonBody):

    Returns:
        Response[Union[ExplainabilityGetConfigResponse400, ExplainabilityGetConfigResponse401, ExplainabilityGetConfigResponse500, Optional[ExplainabilityGetConfigResponse200]]]
    """


    return (await asyncio_detailed(
        client=client,
json_body=json_body,

    )).parsed
